@@ -2,7 +2,6 @@ import importlib.util
 import logging
 
 _torch_available = importlib.util.find_spec("torch") is not None
-_spacy_available = importlib.util.find_spec("spacy") is not None
 
 
 def is_torch_available():
@@ -10,16 +9,6 @@ def is_torch_available():
     return _torch_available
 
 
-def is_spacy_available():
-    """Check if spaCy is available."""
-    return _spacy_available
-
-
-if is_torch_available():
-    import torch
-    from torch import Tensor
-
-
 def get_logger(name: str) -> logging.Logger:
     """
     Return the logger of the given name.
